@@ -11,7 +11,7 @@ If PDL is about arrays, PDL::Dims turns them into hashes
 
 =cut
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use strict;
 
@@ -740,19 +740,22 @@ sub ncop { # named combine operation -- +*-/ ...
 	my @tother=(); 
 	my @aself;
 	my @aother;
+	my @uother; # use other, even though self contains the dim
 	my @add;
 	my @co=();
 	my $i=0;
 	my $j=0;
 	#say "keys self",keys %{$self->hdr};
 	#say "keys other",keys %{$other->hdr};
-	for my $ds (@d) {
+	for my $ds (@d) { # loop over dims in $self
 		my $n=didx($self,$ds);
 		#push @aself,$ds;
-		if (defined ($m=didx($other,$ds))) {
+		if (defined ($m=didx($other,$ds))) { # dim $ds exists also in other
 			push @nself,$n;
 			push @nother,$m;
-		
+			if (dimsize($self,$ds)==1) {
+				push @uother,$ds if (dimsize($other,$ds)>1);
+			}
 	#		say "$ds $m $n";
 	#		say "self $ds $m $n i $i";
 			push @co,$i+0;
@@ -766,10 +769,10 @@ sub ncop { # named combine operation -- +*-/ ...
 			$j++;
 		}
 	}
-	for my $ds (@e) {
+	for my $ds (@e) { # loop over dims in $other 
 		#push @other,$ds;
 		my $n=didx($other,$ds);
-		if (defined ($m=didx($self,$ds))) {
+		if (defined ($m=didx($self,$ds))) { # if present in self, already done
 			1;
 		} else {
 			push @tother,$n;
@@ -781,6 +784,7 @@ sub ncop { # named combine operation -- +*-/ ...
 		}
 	}
 	#say "Co: @co";
+	# reorder piddles 
 	push @aother,@nother if defined ($nother[0]);
 	push @aother,@tother if defined ($tother[0]);
 	push @aself,@nself if defined ($nself[0]);
@@ -789,12 +793,14 @@ sub ncop { # named combine operation -- +*-/ ...
 	my $no=$other->reorder(@aother);
 	#say "keys self",keys %{$self->hdr};
 	#say "keys other",keys %{$other->hdr};
+	# insert missing dimensions
 	for my $n (0..$#tother) { # fill in dummy dims
 		$ns=$ns->dummy($#nself+1,1);
 	}
 	#say "ncop: @aother @aself ",$ns->info,$no->info;
 	#say $self->info,$other->info;
 	#### perform the operation
+	# perform the operation either as method or function
 	if (eval {$ns->can($op)}) {
 		#unshift  @_,0 if ($op eq "atan2" and $_[0] != 0);
 		$res=$ns->$op($no,@_);
@@ -821,6 +827,11 @@ sub ncop { # named combine operation -- +*-/ ...
 	#say "res: ",@{dimname($res)};
 	#$other->hdr;
 	my $i=$self->ndims;
+	for my $ds (@uother) {
+		my $i=didx($res,$ds);
+		rmdim $res,$ds;
+		copy_dim($other,$res,$ds,$i);
+	}
 	for my $ds (0..$#add) {
 		#say "copy $add[$ds]",keys %{$res->hdr};
 		#initdim($res,$add[$ds]);
@@ -829,11 +840,12 @@ sub ncop { # named combine operation -- +*-/ ...
 		$i++;
 	}
 	$res->hdr->{ndims}=$i;
+	#say "self",diminfo $res;
 	#say @{dimname($res)};
 	#say "Co @co";
 	#say "ncop: returning ... ".$res->info;
-	my $err=is_sane($res);
-	#barf "ncop: sanity check failed $err";
+	#my $err=is_sane($res) ;
+	#barf "ncop: sanity check failed $err" if $err;
 	#say "ncop ",diminfo($res);
 	return $res;
 }
@@ -853,8 +865,8 @@ sub sln  :lvalue { # returns a slice by dimnames and patterns
 	}
 	#say "sln: slice string $str";
 	my $ret=$self->slice($str);
-	#say $ret->info;
 	$ret->sethdr($self->hdr_copy);
+	say $ret->info;
 	for my $d (@n) {
 		$str=$s{$d};
 		#say "$d $str";
@@ -864,12 +876,12 @@ sub sln  :lvalue { # returns a slice by dimnames and patterns
 			rmdim ($ret,$d);
 			next;
 		}
-		$str=~m/([+-]?\d+)(:([+-]?\d+)(:([+-]?\d+))?)?/;
-	#	say "$d: 1 $1 2 $2 3 $3 4 $4 5 $5";
+		$str=~m/([+-]?\d+)(:([+-]?\d+)(:([+-]?\d+))?)?/; # regex for a:b:c, a,b,c numbers
+		#say "$d: 1 $1 2 $2 3 $3 4 $4 5 $5";
 		my $step=int ($5)||1;
 		my $size=int abs((($3||$1)-$1)/$step)+1; #
-		my $min=int min pdl($1,$3);
-		my $max=int max pdl($1,$3);
+		my $min=int min pdl($1+0,$3+0);
+		my $max=int max pdl($1+0,$3+0);
 		#say "min $min max $max size $size str $str vals ";
 		dimsize($ret,$d,$size);
 		if (spacing ($self,$d)) { 
